==> wiki3_4_0.zip: wiki3_4_0/plugin/core/EditPage.pm <==
############################################################
# 
# ڡԽץ饰
# 
############################################################
package plugin::core::EditPage;
#===========================================================
# 󥹥ȥ饯
#===========================================================
sub new {
	my $class = shift;
	my $self = {};
	return bless $self,$class;
}

#===========================================================
# μ¹
#===========================================================
sub do_action {
	my $self = shift;
	my $wiki = shift;
	my $cgi = $wiki->get_CGI;
	
	my $pagename = $cgi->param("page");
	my $content  = $cgi->param("content");
	my $template = $cgi->param("template");
	my $time     = $wiki->get_last_modified($pagename);
	
	my $buf = "";
	my $login = $wiki->get_login_info();
	
	if($pagename eq ""){
		return $wiki->error("ڡꤵƤޤ!!");
	}
	if(!$wiki->can_modify_page($pagename)){
		return $wiki->error("ڡԽϵĤƤޤ");
	}
	
	#---------------------------------------------------------------
	# ¸
	if($cgi->param("save") ne ""){
		if($wiki->page_exists($pagename)){
			if($cgi->param("lastmodified") < $time){
				return $wiki->error("ڡϴ̤Υ桼ˤäƹƤޤ");
			}
		}
		
		if($pagename eq "FrontPage" && $content eq ""){
			$buf = "<b>FrontPageϺ뤳ȤϤǤޤ</b>\n";
		} else {
			$wiki->save_page($pagename,$content);
			if($content ne ""){
				$wiki->set_title($pagename."¸ޤ");
				return "<a href=\"$main::script_name?page=".Util::url_encode($pagename)."\">".
				       Util::escapeHTML($pagename)."</a>¸ޤ";
			} else {
				$wiki->set_title($pagename."ޤ");
				return $cgi->escapeHTML($pagename)."ޤ";
			}
		}
	#---------------------------------------------------------------
	# ץӥ塼
	} elsif($cgi->param("preview") ne ""){
		$time = $cgi->param("lastmodified");
		$buf = "ʲΥץӥ塼ǧƤС¸ץܥ򲡤Ƥ<br>";
		if($content eq ""){
			if($pagename eq "FrontPage"){
				$buf = $buf."<b>FrontPageϺ뤳ȤϤǤޤ󡣡</b>";
			} else {
				$buf = $buf."<b>ʥڡƤ϶ǤȤΥڡϺޤ</b>";
			}
		}
		$buf = $buf."<br>".$wiki->process_wiki($content);

	} elsif($wiki->page_exists($pagename)) {
		#ڡ¸ߤ
		$content = $wiki->get_page($pagename);
	} elsif($template ne ""){
		#ƥץ졼Ȥꤵ줿
		$content = $wiki->get_page($template);
	}
	
	#---------------------------------------------------------------
	# ϥե
	$wiki->set_title($pagename."Խ");
	$buf = $buf."<form method=\"post\" action=\"$main::script_name\">\n".
	            "<textarea cols=\"80\" rows=\"20\" name=\"content\">".
	            $cgi->escapeHTML($content)."</textarea><br>\n".
	            "<input type=\"submit\" name=\"save\" value=\"  ¸ \">\n".
	            "<input type=\"submit\" name=\"preview\" value=\"ץӥ塼\">\n".
	            "<input type=\"hidden\" name=\"action\" value=\"EDIT\">\n".
	            "<input type=\"hidden\" name=\"lastmodified\" value=\"".Util::escapeHTML($time)."\">\n".
	            "<input type=\"hidden\" name=\"page\" value=\"".$cgi->escapeHTML($pagename)."\">\n".
	            "</form>\n";
	
	# ץ饰
	$buf .= $wiki->get_editform_plugin();
	
	return $buf;
}

#===========================================================
# ڡɽΥեå᥽å
# Խץ˥塼ͭˤޤ
#===========================================================
sub hook {
	my $self = shift;
	my $wiki = shift;
	my $cgi  = $wiki->get_CGI;
	
	my $pagename = $cgi->param("page");
	if($pagename eq ""){
		$pagename = "FrontPage";
	}
	my $login = $wiki->get_login_info();
	
	# ˥塼
	if(!$main::accept_edit && !defined($login)){
		$wiki->add_menu("","");
		return;
	}
	
	# Խ˥塼
	if($wiki->can_modify_page($pagename)){
		$wiki->add_menu("Խ","$main::script_name?action=EDIT&amp;page=".Util::url_encode($pagename));
	}
}

1;

==> wiki3_4_1.zip: wiki3_4_1/plugin/core/EditPage.pm <==
############################################################
# 
# ڡԽץ饰
# 
############################################################
package plugin::core::EditPage;
use strict;
#===========================================================
# 󥹥ȥ饯
#===========================================================
sub new {
	my $class = shift;
	my $self = {};
	return bless $self,$class;
}

#===========================================================
# μ¹
#===========================================================
sub do_action {
	my $self = shift;
	my $wiki = shift;
	my $cgi = $wiki->get_CGI;
	
	my $pagename = $cgi->param("page");
	my $content  = $cgi->param("content");
	my $template = $cgi->param("template");
	my $time     = $wiki->get_last_modified($pagename);
	
	my $buf = "";
	my $login = $wiki->get_login_info();
	
	if($pagename eq ""){
		return $wiki->error("ڡꤵƤޤ!!");
	}
	if(!$wiki->can_modify_page($pagename)){
		return $wiki->error("ڡԽϵĤƤޤ");
	}
	
	#---------------------------------------------------------------
	# ¸
	if($cgi->param("save") ne ""){
		if($wiki->page_exists($pagename)){
			if($cgi->param("lastmodified") < $time){
				return $wiki->error("ڡϴ̤Υ桼ˤäƹƤޤ");
			}
		}
		
		if($pagename eq "FrontPage" && $content eq ""){
			$buf = "<b>FrontPageϺ뤳ȤϤǤޤ</b>\n";
		} else {
			$wiki->save_page($pagename,$content);
			if($content ne ""){
				$wiki->set_title($pagename."¸ޤ");
				return "<a href=\"".$wiki->config('script_name')."?page=".&Util::url_encode($pagename)."\">".
				       &Util::escapeHTML($pagename)."</a>¸ޤ";
			} else {
				$wiki->set_title($pagename."ޤ");
				return $cgi->escapeHTML($pagename)."ޤ";
			}
		}
	#---------------------------------------------------------------
	# ץӥ塼
	} elsif($cgi->param("preview") ne ""){
		$time = $cgi->param("lastmodified");
		$buf = "ʲΥץӥ塼ǧƤС¸ץܥ򲡤Ƥ<br>";
		if($content eq ""){
			if($pagename eq "FrontPage"){
				$buf = $buf."<b>FrontPageϺ뤳ȤϤǤޤ󡣡</b>";
			} else {
				$buf = $buf."<b>ʥڡƤ϶ǤȤΥڡϺޤ</b>";
			}
		}
		$buf = $buf."<br>".$wiki->process_wiki($content);

	} elsif($wiki->page_exists($pagename)) {
		#ڡ¸ߤ
		$content = $wiki->get_page($pagename);
	} elsif($template ne ""){
		#ƥץ졼Ȥꤵ줿
		$content = $wiki->get_page($template);
	}
	
	#---------------------------------------------------------------
	# ϥե
	$wiki->set_title($pagename."Խ",1);
	$buf = $buf."<form method=\"post\" action=\"".$wiki->config('script_name')."\">\n".
	            "<textarea cols=\"80\" rows=\"20\" name=\"content\">".
	            $cgi->escapeHTML($content)."</textarea><br>\n".
	            "<input type=\"submit\" name=\"save\" value=\"  ¸ \">\n".
	            "<input type=\"submit\" name=\"preview\" value=\"ץӥ塼\">\n".
	            "<input type=\"hidden\" name=\"action\" value=\"EDIT\">\n".
	            "<input type=\"hidden\" name=\"lastmodified\" value=\"".Util::escapeHTML($time)."\">\n".
	            "<input type=\"hidden\" name=\"page\" value=\"".$cgi->escapeHTML($pagename)."\">\n".
	            "</form>\n";
	
	# ץ饰
	$buf .= $wiki->get_editform_plugin();
	
	return $buf;
}

#===========================================================
# ڡɽΥեå᥽å
# Խץ˥塼ͭˤޤ
#===========================================================
sub hook {
	my $self = shift;
	my $wiki = shift;
	my $cgi  = $wiki->get_CGI;
	
	my $pagename = $cgi->param("page");
	if($pagename eq ""){
		$pagename = "FrontPage";
	}
	my $login = $wiki->get_login_info();
	
	# ˥塼
	if($wiki->config('accept_edit')==0 && !defined($login)){
		$wiki->add_menu("","");
		return;
	}
	
	# Խ˥塼
	if($wiki->can_modify_page($pagename)){
		$wiki->add_menu("Խ",$wiki->config('script_name')."?action=EDIT&amp;page=".&Util::url_encode($pagename));
	}
}

1;
